You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by de...@apache.org on 2008/08/31 12:03:13 UTC

svn commit: r690672 - /maven/plugins/trunk/maven-help-plugin/src/main/java/org/apache/maven/plugins/help/DescribeMojo.java

Author: dennisl
Date: Sun Aug 31 03:03:12 2008
New Revision: 690672

URL: http://svn.apache.org/viewvc?rev=690672&view=rev
Log:
o Adjust Javadoc to the new parameter names.

Modified:
    maven/plugins/trunk/maven-help-plugin/src/main/java/org/apache/maven/plugins/help/DescribeMojo.java

Modified: maven/plugins/trunk/maven-help-plugin/src/main/java/org/apache/maven/plugins/help/DescribeMojo.java
URL: http://svn.apache.org/viewvc/maven/plugins/trunk/maven-help-plugin/src/main/java/org/apache/maven/plugins/help/DescribeMojo.java?rev=690672&r1=690671&r2=690672&view=diff
==============================================================================
--- maven/plugins/trunk/maven-help-plugin/src/main/java/org/apache/maven/plugins/help/DescribeMojo.java (original)
+++ maven/plugins/trunk/maven-help-plugin/src/main/java/org/apache/maven/plugins/help/DescribeMojo.java Sun Aug 31 03:03:12 2008
@@ -214,7 +214,7 @@
 
     /**
      * The goal name of a Mojo to describe within the specified Maven Plugin.
-     * If this parameter is specified, only the corresponding Mojo (goal) will be described,
+     * If this parameter is specified, only the corresponding goal (Mojo) will be described,
      * rather than the whole Plugin.
      *
      * @parameter expression="${goal}" alias="mojo"
@@ -223,7 +223,7 @@
     private String goal;
 
     /**
      * This flag specifies that a full (verbose) list of Mojo informations should be given.
      *
      * @parameter expression="${detail}" default-value="false" alias="full"
      * @since 2.1, was <code>full</code> in 2.0.x
@@ -231,7 +231,7 @@
     private boolean detail;
 
     /**
      * This flag specifies that a medium list of Mojo informations should be given.
      *
      * @parameter expression="${medium}" default-value="true"
      * @since 2.0.2
@@ -239,7 +239,7 @@
     private boolean medium;
 
     /**
      * This flag specifies that a minimal list of Mojo informations should be given.
      *
      * @parameter expression="${minimal}" default-value="false"
      * @since 2.1
@@ -415,7 +415,7 @@
             msg.append( "  # mvn help:describe -Dplugin=org.apache.maven.plugins:maven-help-plugin\n" );
             msg.append( "or\n" );
             msg.append( "  # mvn help:describe -DgroupId=org.apache.maven.plugins -DartifactId=maven-help-plugin\n\n" );
-            msg.append( "Try 'mvn help:help -Ddetail=true' for more informations." );
+            msg.append( "Try 'mvn help:help -Ddetail=true' for more information." );
 
             throw new MojoFailureException( msg.toString() );
         }
@@ -223,7 +223,7 @@
 
     /**
-     * This flag specifies that a full (verbose) list of Mojo informations should be given.
+     * This flag specifies that a detailed (verbose) list of Mojo information should be given.
      *
      * @parameter expression="${detail}" default-value="false" alias="full"
@@ -231,7 +231,7 @@
 
     /**
-     * This flag specifies that a medium list of Mojo informations should be given.
+     * This flag specifies that a medium list of Mojo information should be given.
      *
      * @parameter expression="${medium}" default-value="true"
@@ -239,7 +239,7 @@
 
     /**
-     * This flag specifies that a minimal list of Mojo informations should be given.
+     * This flag specifies that a minimal list of Mojo information should be given.
      *
      * @parameter expression="${minimal}" default-value="false"